@@ -21,7 +21,7 @@ class SerumDataApiClient(object):
             return json.loads(response.content)
         return
 
-    def get_market(self, level, market):
+    def get_market_by_level(self, level, market):
         url = self.api_url + 'markets'
         headers = {
             'INSTRUCTION': '1',
@@ -35,3 +35,10 @@ class SerumDataApiClient(object):
             df.set_index('Unnamed: 0', inplace=True)
             return df
         return
+
+
+    def get_market(self, market):
+        results = {}
+        for level in ['level1', 'level2', 'level3']:
+            results[level1] = self.get_market_by_level(level, market)
+        return results 
\ No newline at end of file
